@@ -1,4 +1,3 @@
-
 igraph.to.gexf <- function(igraph.obj, position=NULL) {
   
   g <- igraph.obj
@@ -46,6 +45,10 @@ igraph.to.gexf <- function(igraph.obj, position=NULL) {
   }
   else nVizAtt <- NULL
   
+  if (length(tmpnodes$size)){
+    nVizAtt$size <- tmpnodes$size
+  }
+  
   nVizAtt$position <- position
   
   # Edges Viz att
